# Review 

---

* Author: Felix Example
* Date: 19.10.19

--- 

This is a critical review of the recently published article ...

[Wassermann B, Müller H and Berg G (2019) An Apple a Day: Which Bacteria Do We Eat With Organic and Conventional Apples? Front. Microbiol. 10:1629.](https://www.frontiersin.org/articles/10.3389/fmicb.2019.01629/full)

[TOC]

# Beta Diversity

The authors used unweighted UniFrac distance. Calculating UniFrac distances requires a phylogenetic tree. This was neither provided nor was the method described. I used Muscle to create multiple sequence alignment.

> Beta diversity, based on unweighted UniFraq distance matrix, was visualized by Principle Coordinates Analysis (PCoA) and statistical significance was calculated by Analysis of Similarity (ANOSIM). Source: Wassermann et al. 2019

## PCoA

It is difficult to see any clusters and plotting ellipses for treatments at **confidence level 95%** did not help. 

![](https://gdc-docs.ethz.ch/UniBS/HS2020/BioInf/images/PCoA_UniFrac.jpeg)

My main concern is the low percentage of variation that is explained by the first three axis. It would be much better if Weighted Unifrac would be used instead.

Explained Variance using PCoA

```R
eigen.UF  <- ordinate(d.bac.rare, "PCoA", "Unifrac")
sum(eigen.UF$values$Relative_eig[c(1:3)])
eigen.WUF  <- ordinate(d.bac.rare, "PCoA", "WUnifrac")
sum(eigen.WUF$values$Relative_eig[c(1:3)])
```

* PCA (Unweighted Unifrac) 1-3 = 34.3%
* PCA Weighted Unifrac) 1-3 = 67.4%

---

## Pairwise Comparison

I also failed to confirm all the results of the analysis of similarities. Not only tissue *Seeds* but also *CalyxEnd* were not significantly different between treatments. Unweigthed UniFrac is a qualitativ distance metric giving rare taxa equal weight compare to more abundant taxa. Interestingly, when I consider abundance (Weighted UniFrac) non of the pairwise comparisons is significant any more.

The data indicates a significant difference between location (inside/outside) of the tissue. An interesting finding, relevant for the interpretation of the results.   
 
### Pairwise Comparison using ANOSIM

```
ANOSIM Results (p-values without multiple-hypothesis correction)

Tissue              : R = 0.53, p = 0.001
Treatment           : R = 0.28, p = 0.001
Treatment no Seeds  : R = 0.40, p = 0.001
Treatment-Tissue    : R = 0.78, p = 0.001
Inside/outside      : R = 0.51, p = 0.001
```

### Multilevel Pairwise Comparison using adonis (Permanova)

Table 1: Pairwise - **Unweigthed** UniFrac

| Comparison                 | Df | SumsOfSqs |  F.Model  |     R2     | p.value | p.adjusted | sig |
|----------------------------|:--:|:---------:|:---------:|:----------:|:-------:|:----------:|:---:|
| H-Stem vs C-Stem           |  1 | 0.5785735 | 3.4661078 | 0.36615976 |  0.030  | 0.04096552 |  .  |
| H-StemEnd vs C-StemEnd     |  1 | 0.5630496 | 3.0985516 | 0.34055438 |  0.030  | 0.04096552 |  .  |
| H-Peel vs C-Peel           |  1 | 0.5117392 | 2.2376209 | 0.27163436 |  0.032  | 0.04096552 |  .  |
| H-FruitPulp vs C-FruitPulp |  1 | 0.6023229 | 3.0952419 | 0.34031441 |  0.030  | 0.04096552 |  .  |
| H-Seeds vs C-Seeds         |  1 | 0.3455386 | 1.3945509 | 0.18859170 |  0.061  | 0.06493548 |     |
| H-CalyxEnd vs C-CalyxEnd   |  1 | 0.3542998 | 1.6847801 | 0.21923596 |  0.063  | 0.06600000 |     |

Table 2: Pairwise - **Weigthed** UniFrac

| Comparison                 | Df | SumsOfSqs | F.Model    | R2         | p.value | p.adjusted | sig |
|----------------------------|----|-----------|------------|------------|---------|------------|-----|
| H-Stem vs C-Stem           | 1  | 0.1866470 | 3.3325662  | 0.35709001 | 0.025   | 0.05250000 | NS  |
| H-StemEnd vs C-StemEnd     | 1  | 0.1871960 | 2.8463682  | 0.32175557 | 0.026   | 0.05250000 | NS  |
| H-Peel vs C-Peel           | 1  | 0.5025782 | 10.6873377 | 0.64044594 | 0.022   | 0.05250000 | NS  |
| H-FruitPulp vs C-FruitPulp | 1  | 0.7930154 | 30.1887011 | 0.83420239 | 0.034   | 0.05250000 | NS  |
| H-Seeds vs C-Seeds         | 1  | 0.3537613 | 3.6847942  | 0.38047212 | 0.143   | 0.15472131 | NS  |
| H-CalyxEnd vs C-CalyxEnd   | 1  | 0.1389192 | 1.1419600  | 0.15989449 | 0.197   | 0.20315625 | NS  |

Maybe a hierarchical clustering can help to better understand data structure.   

![](https://gdc-docs.ethz.ch/UniBS/HS2020/BioInf/images/HClust_UniFrac.jpeg)
